# TradeApi
Это библиотека позволит легко взаимодействовать с [API Финама](https://tradeapi.finam.ru/docs/about/). 
С ее помощью возможно: 
*   Получать рыночные данные инструментов:
+ Информацию о стакане 
+ Последние сделки 
+ Свечи
*   Выставлять и контролировать заявки
*   Получать информацию о состоянии счета

Для начала работы необходимо иметь открытый счет в Финам и получить [токен](https://tradeapi.finam.ru/docs/tokens/)
## Установка 

Библиотеку можно установить, запустив команду: 
 `pip install tradeapi`

## Пример 

Примеры доступных функций можно найти тут 


